Module

Trait Module 

pub trait Module: ModuleInternal {
    // Provided method
    fn initial_globals_size(&self) -> usize { ... }
}
The read-only parts of a Lucet program, including its code and initial heap configuration.

Types that implement this trait are suitable for use with Region::new_instance().

Provided Methods

fn initial_globals_size(&self) -> usize

Calculate the initial size in bytes of the module’s Wasm globals.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors